@@ -33,7 +33,9 @@ def now():
     return math.floor(time.time())
 
 
-def uuid():
+def uuid(seed=None):
+    if seed:
+        return str(_uuid.uuid5(_uuid.NAMESPACE_X500, str(seed)))
     return str(_uuid.uuid4())
 
 
@@ -46,14 +48,19 @@ def signature(certificate, data):
 
 
 def get_components():
+    log.info("Getting Vulcan components...")
     r = requests.get("http://komponenty.vulcan.net.pl/UonetPlusMobile/RoutingRules.txt")
-    components = (c.split(",") for c in r.text.split())
-    components = {a[0]: a[1] for a in components}
+    if r.headers["Content-Type"] == "text/plain":
+        components = (c.split(",") for c in r.text.split())
+        components = {a[0]: a[1] for a in components}
+    else:
+        components = {}
     components.update({"FK1": "http://api.fakelog.cf"})
     return components
 
 
 def get_firebase_token():
+    log.info("Getting Firebase token...")
     aid = "4609707972546570896:3626695765779152704"
     device = aid.split(":")[0]
     app = "pl.vulcan.uonetmobile"
